# `uncross new`

The new command creates a new project structure at the provided path.

If the path is a relative or absolute path (containing '.' or '/'), then the `--name` option must be provided. Otherwise, the name of the project will be the name of the provided directory.

For options, run `uncross new --help`.
